Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(330)

Unified Diff: vm/raw_object.h

Issue 11421117: Fix for issue 6359 - Make snapshots platform independent. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/runtime/
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « vm/object.cc ('k') | vm/raw_object.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: vm/raw_object.h
===================================================================
--- vm/raw_object.h (revision 15534)
+++ vm/raw_object.h (working copy)
@@ -432,10 +432,10 @@
}
cpp_vtable handle_vtable_;
- intptr_t instance_size_; // Size if fixed length or 0 if variable length.
+ intptr_t instance_size_in_words_; // Size if fixed len or 0 if variable len.
intptr_t id_; // Class Id, also index in the class table.
- intptr_t type_arguments_field_offset_; // Offset of the type arguments field.
- intptr_t next_field_offset_; // Offset of the next instance field.
+ intptr_t type_arguments_field_offset_in_words_; // Offset of type args fld.
+ intptr_t next_field_offset_in_words_; // Offset of the next instance field.
intptr_t num_native_fields_; // Number of native fields in class.
intptr_t token_pos_;
uint8_t state_bits_; // state, is_const, is_interface, is_implemented.
@@ -602,7 +602,7 @@
RawString* name_;
RawClass* owner_;
RawAbstractType* type_;
- RawInstance* value_; // Offset for instance and value for static fields.
+ RawInstance* value_; // Offset in words for instance and value for static.
RawObject** to() { return reinterpret_cast<RawObject**>(&ptr()->value_); }
intptr_t token_pos_;
« no previous file with comments | « vm/object.cc ('k') | vm/raw_object.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698